//
// database.cpp
//

#include <unistd.h>
#include <stdarg.h>
#include <time.h>
#include <stdio.h>

#include <mysql/mysql.h>

#include "database.h"
#include "dbresult.h"

/**
 * Constructs a MySQL database object
 */

Database::Database (  )
{
	connected = false;
	error = "No connection established";
}

int Database::init (  )
{
	return DB_COMMAND_OK;
}

string Database::error_message (  )
{
	if ( connected == false )
	{
		return error;
	}

	return mysql_error ( &mysql );

}

int Database::connect ( string host, string db )
{
	if ( mysql_connect ( &mysql, host.c_str (  ), DB_USER, DB_PASSWORD ) ==
			 NULL )
	{
		error = "Connect to database failed";
		return DB_ERROR;
	}

	if ( mysql_select_db ( &mysql, db.c_str (  ) ) )
	{
		mysql_close ( &mysql );
		error = "No such database";
		return DB_ERROR;
	}

	connected = true;
	return DB_CONNECTION_OK;
}

int Database::status (  )
{
	if ( connected == false )
	{
		return DB_CONNECTION_NONE;
	}
	return DB_CONNECTION_OK;
}

void Database::disconnect (  )
{
	if ( connected == false )
		return;
	mysql_close ( &mysql );
	connected = false;
}

int Database::reset (  )
{
	return DB_COMMAND_OK;
}

DBResult *Database::exec ( char *sqlFormat, ... )
{
	va_list ap;
	char sqlCommand[5000];

	va_start ( ap, sqlFormat );
	vsnprintf ( sqlCommand, 5000, sqlFormat, ap );
	va_end ( ap );

	return new DBResult ( &mysql, sqlCommand );
}

void Database::exec ( DBResult * res, char *sqlFormat, ... )
{
	va_list ap;
	char sqlCommand[5000];

	va_start ( ap, sqlFormat );
	vsnprintf ( sqlCommand, 5000, sqlFormat, ap );
	va_end ( ap );

	res->init ( &mysql, sqlCommand );
}

/**
 * Destructs a MySQL database object
 */
Database::~Database (  )
{
	disconnect (  );							// Disconnect if connected to database
}
